function structValue = giveStructValue(structure, fieldName, varName, defaultValue)

% This function returns structure.fieldName.varName if existent, otherwise 
% defaultValue.
%
% Output arguments:
% - structValue: structure.fieldName.varName or defaultValue
%
%
% Input arguments:
% - structure: a struct
%
% - fieldName: string; contains name of the field where varName shall be
%   searched in
%
% - varName: string; name of the variable searched for
%
% - defaultValue: this value is assigned if structure.fieldName.varName
%   does not exist
%
%
% Authors:
%   Julius Reiss, reiss@tnt.tu-berlin.de
%   Philipp Schulze, pschulze@math.tu-berlin.de
%
% Version:
%   1.0 (February 15, 2018)
% 

% searching for structure.fieldName.varName and returning if search is
% successful
if(isfield(structure, fieldName))
    if(isfield(structure.(fieldName), varName))
        structValue = structure.(fieldName).(varName) ;
        return
    end
end

% if search was not successful, defaultValue is returned
structValue = defaultValue ;