function D = D_generalPeriodic(N, h, coeffs)

% This function constructs a finite difference matrix based on periodic
% boundary condtions.
%
% Output arguments:
% - D: matrix of dimension NxN; finite difference matrix
%
%
% Input arguments:
% - N: scalar; number of grid points
%
% - h: scalar; grid size
%
% - coeffs: vector; contains coefficients of the finite different stencil
%
%
% Authors:
%   Julius Reiss, reiss@tnt.tu-berlin.de
%   Philipp Schulze, pschulze@math.tu-berlin.de
%
% Version:
%   1.0 (February 15, 2018)
% 

if(length(N)>1)
    error('The function D_generalPeriodic is made for 1D problems only!')
end

diagonalLow = -(length(coeffs)-1)/2                                                                                        ; % number of non-zero lower diagonals (without counting the diagonals which result from the periodicity)
diagonalUp  = -diagonalLow                                                                                                 ; % number of non-zero upper diagonals (without counting the diagonals which result from the periodicity)
B           = [repmat(coeffs(1:-diagonalLow),N,2) repmat(coeffs(1-diagonalLow),N,1) repmat(coeffs(2-diagonalLow:end),N,2)] ; % coefficients of D (multiplied by h)
d           = [diagonalLow:-1 N+(diagonalLow:-1) 0 1:diagonalUp (1:diagonalUp)-N]                                          ; % indices of all non-zero diagonals
D           = spdiags(B,d,N,N)/h                                                                                           ;