function u1 = RK4(u0, dt, rhs)
 
% This function performs one step of the classical explicit 4th-order
% Runge-Kutta method.
%
% Output arguments:
% - u1: vector; contains values at new time step
%
%
% Input arguments:
% - u0: vector; contains values at old time step
%
% - dt: scalar; step size
%
% - rhs: function handle; returns right-hand side of the ODE at hand
%
%
% Authors:
%   Julius Reiss, reiss@tnt.tu-berlin.de
%   Philipp Schulze, pschulze@math.tu-berlin.de
%
% Version:
%   1.0 (February 15, 2018)
% 

% computing the intermediate slopes
k1 = rhs(u0)                   ;
k2 = rhs(u0+0.5*dt*k1)         ;
k3 = rhs(u0+0.5*dt*k2)         ;
k4 = rhs(u0+dt*k3)             ;

% computing u1
u1 = u0+dt*(k1+2*k2+2*k3+k4)/6 ;