function snapshotMatrix = analyticSnapshotMatrix(f, t, xi)

% This function samples the function f to obtain a snapshot matrix.
%
% Output arguments:
% - snapshotMatrix: name is self-explanatory
%
%
% Input arguments:
% - f: function handle with two arguments and one output of the same
%   dimension as the first argument; space- and time-dependent function to
%   be sampled.
%
% - t: vector of discrete time points
%
% - xi: vector of discrete space points (1D)
%
%
% Authors:
%   Julius Reiss, reiss@tnt.tu-berlin.de
%   Philipp Schulze, pschulze@math.tu-berlin.de
%
% Version:
%   1.0 (February 15, 2018)
% 

if(min(size(xi))>1)
    error('The function "analyticSnapshotMatrix" only supports 1D spatial domains!')
end

% initialization of snapshotMatrix
Nxi            = length(xi)           ;
nTimeSteps     = length(t)            ;
snapshotMatrix = NaN(Nxi, nTimeSteps) ;

% assembling snapshotMatrix via sampling f
for i=1:nTimeSteps
    snapshotMatrix(:,i) = f(xi, t(i)) ;
end