function xiInsideDomain = periodicAreaCapturing(xi, leftBoundary, rightBoundary)

% This function takes care that each entry of xi which lies outside of the
% domain [leftBoundary,rightBoundary] is shifted to the inside.
%
% Output arguments:
% - xiInsideDomain: vector of same dimension as xi; modified version of xi
%
%
% Input arguments:
% - xi: vector containing discrete points in space (1D)
%
% - qs: snapshot tensor
%
% - leftBoundary: scalar; specifies the location of the left boundary
%
% - rightBoundary: scalar; specifies the location of the right boundary
%
%
% Authors:
%   Julius Reiss, reiss@tnt.tu-berlin.de
%   Philipp Schulze, pschulze@math.tu-berlin.de
%
% Version:
%   1.0 (February 15, 2018)
% 

if(min(size(xi))>1)
    error('The function "periodicAreaCapturing" only supports 1D spatial domains!')
end

xiInsideDomain    = xi                         ; % initialization of xiInsideDomain
rightGhostIndices = xi>rightBoundary           ; % indices corresponding to entries of xi lying right from the right boundary
leftGhostIndices  = xi<leftBoundary            ; % indices corresponding to entries of xi lying left from the left boundary
L                 = rightBoundary-leftBoundary ; % length of the spatial domain

% shifting xi values into the inside of the computational domain
xiInsideDomain(rightGhostIndices) = leftBoundary+mod(xi(rightGhostIndices)-rightBoundary,L) ; 
xiInsideDomain(leftGhostIndices)  = rightBoundary-mod(leftBoundary-xi(leftGhostIndices),L)  ;