function lx = lagrange(x) 

% This function returns interpolation coefficients based on a Lagrange
% polynomial of degree 3 (assumes x values of given points at [-1 0 1 2]).
%
% Output arguments:
% - lx: vector of size 4; contains interpolation coefficients (i.e.
%   Lagrange basis polynomials evaluated at x)
%
%
% Input arguments:
% - x: scalar; x value where interpolated y value is demanded
%
%
% Authors:
%   Julius Reiss, reiss@tnt.tu-berlin.de
%   Philipp Schulze, pschulze@math.tu-berlin.de
%
% Version:
%   1.0 (February 15, 2018)
% 

points = [-1 0 1 2]  ; % assumed x values of given points
lx     = zeros(4, 1) ; % initialization of lx
enum   = x-points    ; % enumerators of Lagrange basis polynomials evaluated at x

% computing lx
for i=1:4
    denom = points(i)-points ; % denominators of ith Lagrange basis polynomial
    k     = enum./denom      ; % fractions of ith Lagrange basis polynomial evaluated at x
    k(i)  = 1                ; % ith value is set to one since this value does not occur in the Lagrange basis polynomial (it would be infinite)
    lx(i) = prod(k)          ; % ith Lagrange basis polynomial evaluated at x
end