function yNew = replacePartOfVectorByLinearInterpolation(yOld, leftIndex, rightIndex)

% This function replaces a part of the vector yOld by a linear 
% interpolation.
%
% Output arguments:
% - yNew: modified vector
%
%
% Input arguments:
% - yOld: unmodified vector
%
% - leftIndex, rightIndex: scalars; yOld is modified between leftIndex+1
%   and rightIndex-1
%
%
% Authors:
%   Julius Reiss, reiss@tnt.tu-berlin.de
%   Philipp Schulze, pschulze@math.tu-berlin.de
%
% Version:
%   1.0 (February 15, 2018)
% 

yNew                           = yOld                                           ; % initialization of yNew
yLeft                          = yOld(leftIndex)                                ; % value of yOld at leftIndex
yRight                         = yOld(rightIndex)                               ; % value of yOld at rightIndex
m                              = (yRight-yLeft)/(rightIndex-leftIndex)          ; % slope between leftIndex and rightIndex
yNew(leftIndex+1:rightIndex-1) = yLeft+m*((leftIndex+1:rightIndex-1)-leftIndex) ; % replace part of yNew by a linear interpolation between leftIndex+1 and rightIndex-1