% This script performs the mode decomposition based on the proper
% orthogonal decomposition (POD).
%
%
% Authors:
%   Julius Reiss, reiss@tnt.tu-berlin.de
%   Philipp Schulze, pschulze@math.tu-berlin.de
%
% Version:
%   1.0 (February 15, 2018)
% 

% derived data from qs and params
sizeOfQs         = size(qs)                ;
N                = prod(sizeOfQs(1:end-1)) ; % length of one snapshot
relErrorTol      = params.mode.relErrorTol ;
maxNumberOfModes = min(N,sizeOfQs(end))    ; % the number of modes should not be bigger than the row or the column dimension of the snapshot matrix

% computing the svd of the snapshot matrix
qsReshaped = reshape(qs, N, sizeOfQs(end)) ; % snapshot matrix
[U, S, V]  = svd(qsReshaped)               ;

% modes are added until the error tolerance is met (unless it is smaller
% than or equal to 0)
if(relErrorTol>0)
    qsTilde      = U(:,1)*S(1,1)*V(:,1)'                                                ; % POD approximation with one mode
    errorMeasure = giveStructValue(params, 'mode', 'errorMeasure', @relErrorVectorNorm) ; % function for computing the relative error
    relError     = errorMeasure(qsReshaped, qsTilde-qsReshaped)                         ; % current relative error
    i            = 1                                                                    ; % current mode number
    while(relError>params.mode.relErrorTol) % continue until tolerance is met
        i        = i+1                                          ; % increase mode number
        qsTilde  = U(:,1:i)*S(1:i,1:i)*V(:,1:i)'                ; % current POD approximation
        relError = errorMeasure(qsReshaped, qsTilde-qsReshaped) ; % current relative error
        if(i==maxNumberOfModes) % the while loop should terminate anyway but this if condition enforces it explicitly
            break
        end
    end
    U_r = U(:,1:i) ; % kept POD modes
    S_r = S(1:i,1:i) ; % kept singular values
    V_r = V(:,1:i) ; % kept (normalized) amplitudes
else
    U_r = U(:,maxNumberOfModes) ; % if error tolerance is smaller than or equal to zero, take as many singular vectors as necessary
end