function combinedSPODSystem = combineModes(naiveSPODSystem, errorSystem, nModes, nErrorModes) 

% This function assembles the sPOD modes and amplitudes and the residual 
% modes and amplitudes in joint arrays.
%
% Output arguments:
% - combinedSPODSystem: struct containing the modes and (normalized) 
%   amplitudes of the current sPOD approximation and of the residual (also 
%   the shift matrices and the number of frames)
%
%
% Input arguments:
% - naiveSPODSystem: struct containing the modes and amplitudes of the
%   current sPOD approximation(also the shift matrices and the number of 
%   frames)
%
% - errorSystem: struct containing the modes and amplitudes of the residual
%   (also the shift matrices and the number of frames)
%
% - nModes (optional): vector of dimension 1xk, where k is the number of 
%   frames; contains the number of modes per frame which shall be taken 
%   for the sPOD approximation
%
% - nErrorModes (optional): vector of dimension 1xk, where k is the number 
%   of frames; contains the number of modes per frame which shall be taken 
%   for the residual
%
%
% Authors:
%   Julius Reiss, reiss@tnt.tu-berlin.de
%   Philipp Schulze, pschulze@math.tu-berlin.de
%
% Version:
%   1.0 (February 15, 2018)
% 

combinedSPODSystem = naiveSPODSystem ; % initialization of combinedSPODSystem

% assembling combinedSPODSystem
if(nargin<=2)
    for i = 1:naiveSPODSystem.nSubSpaces % loop over the velocity frames
        combinedSPODSystem.U{i} = [naiveSPODSystem.U{i} errorSystem.U{i}] ;     
        combinedSPODSystem.V{i} = [naiveSPODSystem.V{i} errorSystem.V{i}] ;     
    end
else
    for i = 1:naiveSPODSystem.nSubSpaces % loop over the velocity frames
        combinedSPODSystem.U{i} = [naiveSPODSystem.U{i}(:,1:nModes(i)) errorSystem.U{i}(:,1:nErrorModes(i))] ;     
        combinedSPODSystem.V{i} = [naiveSPODSystem.V{i}(:,1:nModes(i)) errorSystem.V{i}(:,1:nErrorModes(i))] ;     
    end
end
