function csNew = csPostProcessingTwoShocks(csOld)

% This function performs the post-processing of the tracked shifts for the
% "twoCrossingShocks" case.
%
% Output arguments:
% - csNew: matrix of dimension mxk, where m is the number of time steps and k
%   is the number of velocity frames; contains the modified shift values 
%   for each velocity frame and each discrete time step
%
%
% Input arguments:
% - csOld: matrix of dimension mxk, where m is the number of time steps and k
%   is the number of velocity frames; contains the unmodified shift values 
%   for each velocity frame and each discrete time step
%
%
% Authors:
%   Julius Reiss, reiss@tnt.tu-berlin.de
%   Philipp Schulze, pschulze@math.tu-berlin.de
%
% Version:
%   1.0 (February 15, 2018)
% 

% swaping a part of the two columns of csOld
csNew             = csOld              ; % initialization of csNew
csTemp            = csOld              ; % temporary variable for the swap
csNew(3182:end,1) = csTemp(3182:end,2) ;
csNew(3182:end,2) = csTemp(3182:end,1) ;

% performing a linear interpolation in the region around the border between
% modified and unmodified part of the columns in order to avoid jumps
csNew(:,1) = replacePartOfVectorByLinearInterpolation(csNew(:,1), 3130, 3230) ;
csNew(:,2) = replacePartOfVectorByLinearInterpolation(csNew(:,2), 3130, 3230) ;