function shiftedf = shiftFunction(f, cs, leftBoundary, rightBoundary)

% This function applies a time-dependent shift to the function f (assuming
% periodic boundary conditions at leftBoundary and rightBoundary).
%
% Output arguments:
% - shiftedf: function handle with two arguments; like function f but
%   shifted in space with a time-dependent shift
%
%
% Input arguments:
% - f: function handle with one argument
%
% - cs: scalar; constand shift velocity
%
% - leftBoundary: scalar; location of left boundary
%
% - rightBoundary: scalar; location of right boundary
%
%
% Authors:
%   Julius Reiss, reiss@tnt.tu-berlin.de
%   Philipp Schulze, pschulze@math.tu-berlin.de
%
% Version:
%   1.0 (February 15, 2018)
% 

if(~isscalar(cs))
    error('The function "shiftFunction" accepts the variable cs only to be a scalar!')
end

shiftedf = @(xi,t)f(periodicAreaCapturing(xi-t*cs,leftBoundary,rightBoundary)) ;